pub enum Error {
Format(String),
Number(String),
TimeUnit(String),
Never,
}Expand description
Describes an error during the parsing of a timestamp.
Variants
Format(String)
The timestamp is incorrectly formatted.
Number(String)
The timestamp contains a component that cannot be parsed into a number, or the number overflowed.
TimeUnit(String)
The timestamp contains a component that cannot be parsed into a time unit.
Never
The timestamp is invalid in the given timezone.